Crate streamdeck_rs

Crate streamdeck_rs 

Re-exports

pub use crate::registration::RegistrationInfo;
pub use crate::socket::StreamDeckSocket;

Modules

logging
registration
socket

Structs

ApplicationPayload
Information about a monitored application that has launched or terminated.
Coordinates
The location of a key on a device.
DeviceInfo
Information about a hardware device.
DeviceSize
The size of a device in keys.
DialDownPayload
Additional information about an encoder press event.
DialRotatePayload
Additional information about an encoder rotate event.
DialUpPayload
Additional information about an encoder release event.
GlobalSettingsPayload
The new global settings.
ImagePayload
The image to set as part of a SetImage message.
KeyPayload
Additional information about the key pressed.
LogMessagePayload
A log message.
ProfilePayload
The profile to activate as part of a SwitchToProfile message.
SetFeedbackLayoutPayload
A layout update message.
SetTriggerDescriptionPayload
A trigger description update message.
StatePayload
The state to set as part of a SetState message.
TitleParameters
Style information for a title.
TitleParametersPayload
The new title of a key.
TitlePayload
The title to set as part of a SetTitle message.
TouchTapPayload
Additional information about a touch tap event.
UrlPayload
The URL to launch as part of a OpenUrl message.
VisibilityPayload
Additional information about a key’s appearance.

Enums

Alignment
The vertical alignment of a title.
Color
DeviceType
The type of connected hardware device.
Message
A message received from the Stream Deck software.
MessageOut
A message to be sent to the Stream Deck software.
Target
The target of a command.