[−][src]Enum streamdeck_rs::Message
A message received from the Stream Deck software.
Grepresents the global settings that are persisted within the Stream Deck software.Srepresents the settings that are persisted within the Stream Deck software.Mrepresents the messages that are received from the property inspector.
Variants
A key has been pressed.
Fields of KeyDown
action: StringThe uuid of the action.
context: StringThe instance of the action (key or part of a multiaction).
device: StringThe device where the key was pressed.
payload: KeyPayload<S>Additional information about the key press.
A key has been released.
Fields of KeyUp
action: StringThe uuid of the action.
context: StringThe instance of the action (key or part of a multiaction).
device: StringThe device where the key was pressed.
payload: KeyPayload<S>Additional information about the key press.
An instance of the action has been added to the display.
Fields of WillAppear
action: StringThe uuid of the action.
context: StringThe instance of the action (key or part of a multiaction).
device: Option<String>The device where the action will appear, or None if it does not appear on a device.
payload: VisibilityPayload<S>Additional information about the action's appearance.
An instance of the action has been removed from the display.
Fields of WillDisappear
action: StringThe uuid of the action.
context: StringThe instance of the action (key or part of a multiaction).
device: Option<String>The device where the action was visible, or None if it was not on a device.
payload: VisibilityPayload<S>Additional information about the action's appearance.
The title has changed for an instance of an action.
Fields of TitleParametersDidChange
action: StringThe uuid of the action.
context: StringThe instance of the action (key or part of a multiaction).
device: Option<String>The device where the action is visible, or None if it is not on a device.
payload: TitleParametersPayload<S>Additional information about the new title.
A device has connected.
Fields of DeviceDidConnect
device: StringThe ID of the device that has connected.
device_info: DeviceInfoInformation about the device.
A device has disconnected.
Fields of DeviceDidDisconnect
device: StringThe ID of the device that has disconnected.
An application monitored by the manifest file has launched.
Fields of ApplicationDidLaunch
payload: ApplicationPayloadInformation about the launched application.
An application monitored by the manifest file has terminated.
Fields of ApplicationDidTerminate
payload: ApplicationPayloadInformation about the terminated application.
The property inspector has sent data.
Fields of SendToPlugin
The application has sent settings for an action.
This message is sent in response to GetSettings, but also after the property inspector changes the settings.
Fields of DidReceiveSettings
action: StringThe uuid of the action.
context: StringThe instance of the action (key or part of a multiaction).
device: StringThe device where the action exists.
payload: KeyPayload<S>The current settings for the action.
The property inspector for an action has become visible.
Fields of PropertyInspectorDidAppear
The property inspector for an action is no longer visible.
Fields of PropertyInspectorDidDisappear
The application has sent settings for an action.
This message is sent in response to GetGlobalSettings, but also after the property inspector changes the settings.
Fields of DidReceiveGlobalSettings
payload: GlobalSettingsPayload<G>The current settings for the action.
The computer has resumed from sleep.
Added in Stream Deck software version 4.3.
An event from an unsupported version of the Stream Deck software.
This occurs when the Stream Deck software sends an event that is not understood. Usually this will be because the Stream Deck software is newer than the plugin, and it should be safe to ignore these.