[−][src]Enum streamdeck_rs::MessageOut
A message to be sent to the Stream Deck software.
Grepresents the global settings that are persisted within the Stream Deck software.Srepresents the action settings that are persisted within the Stream Deck software.Mrepresents the messages that are sent to the property inspector.
Variants
Set the title of an action instance.
Fields of SetTitle
context: StringThe instance of the action (key or part of a multiaction).
payload: TitlePayloadThe title to set.
Set the image of an action instance.
Fields of SetImage
context: StringThe instance of the action (key or part of a multiaction).
payload: ImagePayloadThe image to set.
Temporarily overlay the key image with an alert icon.
Fields of ShowAlert
context: StringThe instance of the action (key or part of a multiaction).
Temporarily overlay the key image with a checkmark.
Fields of ShowOk
context: StringThe instance of the action (key or part of a multiaction).
Retrieve settings for an instance of an action via DidReceiveSettings.
Fields of GetSettings
context: StringThe instance of the action (key or part of a multiaction).
Store settings for an instance of an action.
Fields of SetSettings
context: StringThe instance of the action (key or part of a multiaction).
payload: SThe settings to save.
Set the state of an action.
Normally, Stream Deck changes the state of an action automatically when the key is pressed.
Fields of SetState
context: StringThe instance of the action (key or part of a multiaction).
payload: StatePayloadThe desired state.
Send data to the property inspector.
Fields of SendToPropertyInspector
Select a new profile.
Fields of SwitchToProfile
context: StringThe instance of the action (key or part of a multiaction).
device: StringThe device to change the profile of.
payload: ProfilePayloadThe profile to activate.
Open a URL in the default browser.
Fields of OpenUrl
payload: UrlPayloadThe url to open.
Retrieve plugin settings for via DidReceiveGlobalSettings.
Fields of GetGlobalSettings
context: StringThe instance of the action (key or part of a multiaction).
Store plugin settings.
Fields of SetGlobalSettings
context: StringThe instance of the action (key or part of a multiaction).
payload: GThe settings to save.
Write to the log.
Fields of LogMessage
payload: LogMessagePayloadThe message to log.