Module registration

Module registration 

Structs

RegistrationInfo
Information about the environment the plugin is being loaded into.
RegistrationInfoApplication
Information about the Stream Deck software.
RegistrationInfoDevice
Information about a connected device.
RegistrationInfoPlugin
Information about the plugin
RegistrationParams
Registration parameters provided to the plugin on startup.
UserColors
The user’s preferred colors

Enums

Language
The language the Stream Deck software is running in.
Platform
The platform on which the Stream Deck software is running.
RegistrationParamsError
An error that occurred while collecting the registration parameters.