pub enum RegistrationParamsError {
NoPort,
BadPort(ParseIntError),
NoUuid,
NoEvent,
NoInfo,
BadInfo(Error),
}Expand description
An error that occurred while collecting the registration parameters.
Variants
NoPort
The port number was not found.
BadPort(ParseIntError)
The port number was found but could not be parsed.
NoUuid
The uuid was not found.
NoEvent
The registration event to send was not found.
NoInfo
The registration environment info was not found.
BadInfo(Error)
The registration environment info could not be parsed.