[][src]Struct streamdeck_rs::registration::RegistrationParams

pub struct RegistrationParams {
    pub port: u16,
    pub uuid: String,
    pub event: String,
    pub info: RegistrationInfo,
}

Registration parameters provided to the plugin on startup.

Official Documentation

Fields

port: u16

The web socket port listening for the plugin.

uuid: String

The uuid of the plugin.

event: String

The event the plugin should send to register with the Stream Deck software.

info: RegistrationInfo

Information about the environment the plugin is being loaded into.

Methods

impl RegistrationParams[src]

pub fn from_args<I: IntoIterator<Item = String>>(
    args: I
) -> Result<RegistrationParams, RegistrationParamsError>
[src]

Pull the registration parameters out of a command line.

Examples

RegistrationParams::from_args(env::args())