pub struct UserColors {
pub button_mouse_over_background_color: Option<Color>,
pub button_pressed_background_color: Option<Color>,
pub button_pressed_border_color: Option<Color>,
pub button_pressed_text_color: Option<Color>,
pub highlight_color: Option<Color>,
}Expand description
The user’s preferred colors
Fields
Color that denotes the background of a button that is being moused over.
Color that denotes the background of a pressed button.
Color that denotes the border of a pressed button.
Color that denotes the text of a pressed button.
highlight_color: Option<Color>Color of highlighted text.