[−][src]Module streamdeck_rs::socket
Structs
| Address | Represents an address to connect to. |
| Connect | An in-progress connection to the Stream Deck software. |
| StreamDeckSocket | Provides encoding and decoding for messages sent to/from the Stream Deck software. |
Enums
| ConnectError | Represents an error that occurred while connecting to and registering with the Stream Deck software. |
| StreamDeckSocketError | Represents an error that occurred reading or writing the web socket. |