pub struct SetTriggerDescriptionPayload {
pub long_touch: Option<String>,
pub push: Option<String>,
pub rotate: Option<String>,
pub touch: Option<String>,
}Expand description
A trigger description update message.
Fields
long_touch: Option<String>A value that describes the long-touch interaction with the touch display.
push: Option<String>A value that describes the push interaction with the dial.
rotate: Option<String>A value that describes the rotate interaction with the dial.
touch: Option<String>A value that describes the touch interaction with the touch display.