[−][src]Enum streamdeck_rs::registration::RegistrationParamsError
An error that occurred while collecting the registration parameters.
Variants
The port number was not found.
BadPort(ParseIntError)The port number was found but could not be parsed.
The uuid was not found.
The registration event to send was not found.
The registration environment info was not found.
BadInfo(Error)The registration environment info could not be parsed.