[−][src]Enum streamdeck_rs::registration::RegistrationParamsError
An error that occurred while collecting the registration parameters.
Variants
NoPortThe port number was not found.
BadPort(ParseIntError)The port number was found but could not be parsed.
NoUuidThe uuid was not found.
NoEventThe registration event to send was not found.
NoInfoThe registration environment info was not found.
BadInfo(Error)The registration environment info could not be parsed.