[−][src]Struct streamdeck_rs::registration::RegistrationParams
Registration parameters provided to the plugin on startup.
Fields
port: u16The web socket port listening for the plugin.
uuid: StringThe uuid of the plugin.
event: StringThe event the plugin should send to register with the Stream Deck software.
info: RegistrationInfoInformation about the environment the plugin is being loaded into.
Methods
impl RegistrationParams[src]
pub fn from_args<I: IntoIterator<Item = String>>(
args: I
) -> Result<RegistrationParams, RegistrationParamsError>[src]
args: I
) -> Result<RegistrationParams, RegistrationParamsError>
Pull the registration parameters out of a command line.
Examples
RegistrationParams::from_args(env::args())